<?xml version="1.0" ?><!DOCTYPE TS><TS language="nn" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <location filename="src/AboutView.cpp" line="21"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>Det finst eit liv utanfor nettlesaren!</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="22"/>
        <source>Version %1</source>
        <translation>Versjon %1</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="26"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 er fri programvare, men utviklinga tek dyrebar tid.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="27"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Ver venleg og &lt;a href=&apos;%1&apos;&gt;doner&lt;/a&gt; for å støtta vidare utvikling av %2.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="31"/>
        <source>You may want to try my other apps as well:</source>
        <translation>Du er kanskje interessert i å prøva dei andre programma mine:</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="34"/>
        <source>%1, a YouTube music player</source>
        <translation>%1, ein musikkspelar for YouTube</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="38"/>
        <source>%1, a music player</source>
        <translation>%1, ein musikkspelar</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="44"/>
        <source>Translate %1 to your native language using %2</source>
        <translation>Omset %1 til morsmålet ditt med %2</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="49"/>
        <source>Icon designed by %1.</source>
        <translation>Ikonet er utforma av %1.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="53"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Utgjeve under &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="65"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="src/AboutView.h" line="25"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="src/AboutView.h" line="27"/>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Alt du alltid har ynskt å vita om %1, men aldri tort spørja om</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="56"/>
        <source>Clear</source>
        <translation>Nullstill</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <location filename="local/src/demostartupview.cpp" line="35"/>
        <source>Please license %1</source>
        <translation>Ver venleg og lisensier %1</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="39"/>
        <source>This demo has expired.</source>
        <translation>Demoen har laupt ut.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="41"/>
        <source>The full version allows you to download videos longer than %1 minutes and to watch videos without interruptions.</source>
        <translation>Den fullstendige utgåva lar deg lasta ned videoar som er meir enn %1 minutt lange, og lar deg sjå videoar utan avbrot.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="43"/>
        <source>This demo will expire in %1 days.</source>
        <translation>Denne demoen lauper ut om %1 dagar.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="45"/>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Ved å kjøpa den fullstendige utgåva, støttar du arbeidet lagt inn i å skapa %1.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="57"/>
        <source>Use Demo</source>
        <translation>Bruk demoen</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="65"/>
        <source>Get the full version</source>
        <translation>Kjøp fullversjonen</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="src/downloaditem.cpp" line="308"/>
        <source>bytes</source>
        <translation>byte</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="311"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="314"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="330"/>
        <source>bytes/sec</source>
        <translation>byte/sek</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="333"/>
        <source>KB/sec</source>
        <translation>KB/sek</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="336"/>
        <source>MB/sec</source>
        <translation>MB/sek</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="342"/>
        <source>seconds</source>
        <translation>sekund</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="345"/>
        <source>minutes</source>
        <translation>minutt</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="348"/>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 gjenstår</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="src/downloadmanager.cpp" line="47"/>
        <source>This is just the demo version of %1.</source>
        <translation>Dette er berre demoutgåva av %1.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="49"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Han kan berre lasta ned videoar på under %1 minutt, for at du skal kunna prøva ut nedlastingsfunksjonen.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="55"/>
        <source>Continue</source>
        <translation>Hald fram</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="56"/>
        <source>Get the full version</source>
        <translation>Kjøp fullversjonen</translation>
    </message>
    <message numerus="yes">
        <location filename="src/downloadmanager.cpp" line="137"/>
        <source>%n Download(s)</source>
        <translation><numerusform>%n nedlasting</numerusform><numerusform>%n nedlastingar</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="src/downloadsettings.cpp" line="14"/>
        <source>Change location...</source>
        <translation>Endra stad …</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="38"/>
        <source>Choose the download location</source>
        <translation>Vel nedlastingsmappe</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="49"/>
        <source>Download location changed.</source>
        <translation>Nedlastingsmappe endra.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="51"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Nedlastingar som er i gong vil likevel lagrast i den førre mappa.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="63"/>
        <source>Downloading to: %1</source>
        <translation>Lastar ned til: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="src/downloadview.cpp" line="18"/>
        <location filename="src/downloadview.h" line="22"/>
        <source>Downloads</source>
        <translation>Nedlastingar</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="src/globalshortcuts.cpp" line="16"/>
        <source>Play</source>
        <translation>Spel av</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="17"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="18"/>
        <source>Play/Pause</source>
        <translation>Spel av/pause</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="19"/>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="20"/>
        <source>Stop playing after current track</source>
        <translation>Stopp avspelinga etter denne videoen</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="21"/>
        <source>Next track</source>
        <translation>Neste video</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="22"/>
        <source>Previous track</source>
        <translation>Førre video</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="23"/>
        <source>Increase volume</source>
        <translation>Auk lydvolumet</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="24"/>
        <source>Decrease volume</source>
        <translation>Senk lydvolumet</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="25"/>
        <source>Mute</source>
        <translation>Lydlaus</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="26"/>
        <source>Seek forward</source>
        <translation>Søk framover</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="27"/>
        <source>Seek backward</source>
        <translation>Søk bakover</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="src/ListModel.cpp" line="51"/>
        <source>Searching...</source>
        <translation>Søkjer …</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="52"/>
        <source>Show %1 More</source>
        <translation>Vis %1 fleire</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="53"/>
        <source>No videos</source>
        <translation>Ingen videoar</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="54"/>
        <source>No more videos</source>
        <translation>Ingen fleire videoar</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="src/loadingwidget.cpp" line="71"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="src/MainWindow.cpp" line="160"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stopp</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="161"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Stoppar avspeling og går tilbake til søkjevisinga</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="179"/>
        <source>S&amp;kip</source>
        <translation>&amp;Hopp over</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="180"/>
        <source>Skip to the next video</source>
        <translation>Hopp til neste video</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="186"/>
        <location filename="src/MainWindow.cpp" line="835"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="187"/>
        <location filename="src/MainWindow.cpp" line="836"/>
        <source>Pause playback</source>
        <translation>Set avspeling på pause</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="193"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Fullskjerm</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="194"/>
        <source>Go full screen</source>
        <translation>Fullskjermvising</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="210"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Gøym spelelista og verktøylinja</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="223"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Gå til video-sida på YouTube og set avspelinga på pause</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="230"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopier denne YouTube video-lenkja til utklippstavla</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="237"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopier denne videostraumlenkja til utklippstavla</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="244"/>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Finn andre deler av videoen, vonleg i rett følgje</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="250"/>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="251"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Fjern valde videoar frå spelelista</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="257"/>
        <source>Move &amp;Up</source>
        <translation>Flytt &amp;opp</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="258"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Flytt opp valde videoar i spelelista</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="264"/>
        <source>Move &amp;Down</source>
        <translation>Flytt &amp;ned</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="265"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Flytt ned valde videoar i spelelista</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="276"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Fjern all søkjehistorie. Kan ikkje angrast.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="281"/>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="284"/>
        <source>Bye</source>
        <translation>Farvel</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="288"/>
        <source>&amp;Website</source>
        <translation>&amp;Nettstad</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="290"/>
        <source>%1 on the Web</source>
        <translation>%1 på internett</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="296"/>
        <source>Please support the continued development of %1</source>
        <translation>Vi håpar du kan bidra til vidare utvikling av %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="301"/>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="303"/>
        <source>Info about %1</source>
        <translation>Informasjon om %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="311"/>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="330"/>
        <source>Mute volume</source>
        <translation>Lydlaus</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="359"/>
        <location filename="src/MainWindow.cpp" line="1179"/>
        <source>&amp;Downloads</source>
        <translation>&amp;Nedlastingar</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="360"/>
        <source>Show details about video downloads</source>
        <translation>Vis detaljar om videonedlasting</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="368"/>
        <source>&amp;Download</source>
        <translation>&amp;Nedlasting</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="369"/>
        <source>Download the current video</source>
        <translation>Last ned denne videoen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="381"/>
        <source>Share the current video using %1</source>
        <translation>Del denne videoen med %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="393"/>
        <source>&amp;Email</source>
        <translation>&amp;Epost</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="394"/>
        <source>Email</source>
        <translation>Epost</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="398"/>
        <source>&amp;Close</source>
        <translation>&amp;Steng</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="403"/>
        <source>&amp;Float on Top</source>
        <translation>&amp;Vis over andre</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="408"/>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Stopp etter denne videoen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="445"/>
        <source>&amp;Application</source>
        <translation>&amp;Program</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="447"/>
        <source>Buy %1...</source>
        <translation>Kjøp %1 …</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="458"/>
        <source>&amp;Playback</source>
        <translation>&amp;Avspeling</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="472"/>
        <source>&amp;Playlist</source>
        <translation>&amp;Speleliste</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="479"/>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="490"/>
        <source>&amp;View</source>
        <translation>&amp;Vising</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="497"/>
        <source>&amp;Share</source>
        <translation>&amp;Del</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="509"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="586"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Trykk på %1 for å auka lydvolumet, %2 for å senka</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="748"/>
        <location filename="src/MainWindow.cpp" line="754"/>
        <source>Opening %1</source>
        <translation>Opnar %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="787"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Vil du avslutta %1 medan ei nedlasting er i gang?</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="788"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Vis du stenger %1 no, vil nedlastinga avbrytast</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="793"/>
        <source>Close and cancel download</source>
        <translation>Steng og avbryt nedlastinga</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="794"/>
        <source>Wait for download to finish</source>
        <translation>Vent medan nedlastinga vert fullførd</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="940"/>
        <source>Leave &amp;Full Screen</source>
        <translation>Forlat &amp;fullskjerm</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1283"/>
        <source>%1 version %2 is now available.</source>
        <translation>Versjon %2 av %1 er no tilgjengeleg.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1297"/>
        <source>Remind me later</source>
        <translation>Minn meg på det seinare</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1294"/>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation>Last ned %1 igjen frå lenkja du fekk via epost, og installer på nytt, for å få den oppdaterte versjonen.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1301"/>
        <source>Update</source>
        <translation>Oppdater</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="828"/>
        <source>Error: %1</source>
        <translation>Feil: %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="169"/>
        <source>P&amp;revious</source>
        <translation>&amp;Førre</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="170"/>
        <source>Go back to the previous track</source>
        <translation>Gå til førre spor</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="209"/>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Kompakt modus</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="222"/>
        <source>Open the &amp;YouTube Page</source>
        <translation>Opna &amp;YouTube-sida</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="229"/>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopier YouTube-&amp;lenkja</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="236"/>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Kopier &amp;URL-en til videostraumen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="243"/>
        <source>Find Video &amp;Parts</source>
        <translation>Finn &amp;delane av videoen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="271"/>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Tøm siste søk</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="295"/>
        <source>Make a &amp;Donation</source>
        <translation>&amp;Doner</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="352"/>
        <source>&amp;Manually Start Playing</source>
        <translation>Start avspelinga &amp;manuelt</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="353"/>
        <source>Manually start playing videos</source>
        <translation>Spel av videoar manuelt</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="848"/>
        <source>&amp;Play</source>
        <translation>&amp;Spel av</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="849"/>
        <source>Resume playback</source>
        <translation>Gjenoppta avspeling</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1055"/>
        <source>Remaining time: %1</source>
        <translation>Tid igjen: %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1113"/>
        <source>Volume at %1%</source>
        <translation>Volum %1%</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1119"/>
        <source>Volume is muted</source>
        <translation>Lydlaust er på</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1122"/>
        <source>Volume is unmuted</source>
        <translation>Lydlaust er av</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1129"/>
        <source>Maximum video definition set to %1</source>
        <translation>Maksimum videodefinisjon sett til %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1165"/>
        <source>Your privacy is now safe</source>
        <translation>Privatlivet ditt er no sikkert</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1180"/>
        <source>Downloads complete</source>
        <translation>Nedlastingar fullførde</translation>
    </message>
    <message>
        <location filename="local/mac/macsupport.cpp" line="58"/>
        <source>&amp;Window</source>
        <translation>&amp;Vindauge</translation>
    </message>
    <message>
        <location filename="local/mac/macsupport.cpp" line="61"/>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimer</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="src/MediaView.cpp" line="35"/>
        <source>Most relevant</source>
        <translation>Mest relevant</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="42"/>
        <source>Most recent</source>
        <translation>Nyaste</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="49"/>
        <source>Most viewed</source>
        <translation>Mest sett</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="521"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Du kan no lima inn YouTube-lenkja i eit anna program</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="529"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Du kan no lima inn videostraumlenkja i eit anna program</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="530"/>
        <source>The link will be valid only for a limited time.</source>
        <translation>Denne lenkja vil berre vera gyldig i ei avgrensa tid.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="629"/>
        <source>This is just the demo version of %1.</source>
        <translation>Dette er berre demoutgåva av %1.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="630"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Dette lèt prøva ut programmet og sjå om det er noko for deg.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="660"/>
        <source>Continue</source>
        <translation>Hald fram</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="749"/>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>av</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="761"/>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>del</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="763"/>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episode</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="821"/>
        <source>Sent from %1</source>
        <translation>Send frå %1</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="637"/>
        <source>Get the full version</source>
        <translation>Kjøp fullversjonen</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="682"/>
        <source>Downloading %1</source>
        <translation>Lastar ned %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <location filename="src/networkaccess.cpp" line="214"/>
        <source>Network error: %1</source>
        <translation>Feil på nettverket: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="170"/>
        <source>%1 views</source>
        <translation>%1 visingar</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="286"/>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 av %2 (%3) — %4</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="293"/>
        <source>Preparing</source>
        <translation>Førebur</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="295"/>
        <source>Failed</source>
        <translation>Feila</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="297"/>
        <source>Completed</source>
        <translation>Ferdig</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="299"/>
        <source>Stopped</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="335"/>
        <source>Stop downloading</source>
        <translation>Stopp nedlasting</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="345"/>
        <source>Show in %1</source>
        <translation>Vis i %1</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="347"/>
        <source>Open parent folder</source>
        <translation>Opna vertsmappa</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="356"/>
        <source>Restart downloading</source>
        <translation>Start nedlastinga på nytt</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="177"/>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="src/SearchView.cpp" line="79"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Velkomen til &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="46"/>
        <source>Get the full version</source>
        <translation>Kjøpfullversjonen</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="93"/>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation>Skriv</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="98"/>
        <source>a keyword</source>
        <translation>eit nøkkelord</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="99"/>
        <source>a channel</source>
        <translation>ein kanal</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="104"/>
        <source>to start watching videos.</source>
        <translation>for å å sjå videoar.</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="128"/>
        <source>Watch</source>
        <translation>Snurr film</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="146"/>
        <source>Recent keywords</source>
        <translation>Siste søkjeord</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="159"/>
        <source>Recent channels</source>
        <translation>Siste kanalar</translation>
    </message>
    <message>
        <location filename="src/SearchView.h" line="26"/>
        <source>Make yourself comfortable</source>
        <translation>Finn deg til rette</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="src/video.cpp" line="200"/>
        <source>Cannot get video stream for %1</source>
        <translation>Kan ikkje henta videostraumen til %1</translation>
    </message>
    <message>
        <location filename="src/video.cpp" line="218"/>
        <source>Network error: %1 for %2</source>
        <translation>Feil på nettverket: %1 for %2</translation>
    </message>
</context>
</TS>